<h2 align="center">
  GLOGGER 
  <h3 align="center">
    Log Aggregator
    <p align="center">
       </br>
  <img src="https://i.imgur.com/t9HaoC7.png" alt="Glogger" />
</p>
</h3>
</h2

[@gfrancodev/glogger](https://github.com/gfrancodev/glogger) 


## Developers
- Author - [Gustavo Franco](https://gfrancodev.com)
- Linkedin - [@gfrancodev](https://www.linkedin.com/in/gfrancodev/)

## License

[MIT licensed](LICENSE)
